@@ -6,7 +6,7 @@ use Moose;
 use MooseX::MarkAsMethods (autoclean => 1);
 use MooseX::Types::Moose qw(Str);
 
-use Module::Corelist;
+use Module::CoreList;
 use English qw(-no_match_vars);
 
 use Pinto::Types qw(Version);
@@ -17,7 +17,7 @@ use overload ('""' => 'to_string');
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_03'; # VERSION
+our $VERSION = '0.065_04'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -104,7 +104,7 @@ Pinto::PackageSpec - Specifies a package by name and version
 
 =head1 VERSION
 
-version 0.065_03
+version 0.065_04
 
 =head1 METHODS
 
